@@ -6,7 +6,7 @@
 //
 // This file is expected not to perform any asynchronous operations itself
 // when being executed - those should be done in either
-// `lib/internal/bootstrap/pre_execution.js` or in main scripts. The majority
+// `lib/internal/process/pre_execution.js` or in main scripts. The majority
 // of the code here focuses on setting up the global proxy and the process
 // object in a synchronous manner.
 // As special caution is given to the performance of the startup process,
@@ -18,7 +18,7 @@
 //   modules to use.
 // - `lib/internal/bootstrap/loaders.js`: to setup internal binding and
 //   module loaders, including `process.binding()`, `process._linkedBinding()`,
-//   `internalBinding()` and `NativeModule`.
+//   `internalBinding()` and `BuiltinModule`.
 //
 // This file is run to bootstrap both the main thread and the worker threads.
 // After this file is run, certain properties are setup according to the
@@ -28,7 +28,7 @@
 // Then, depending on how the Node.js instance is launched, one of the main
 // scripts in `lib/internal/main` will be selected by C++ to start the actual
 // execution. They may run additional setups exported by
-// `lib/internal/bootstrap/pre_execution.js` depending on the runtime states.
+// `lib/internal/process/pre_execution.js` depending on the runtime states.
 
 'use strict';
 
@@ -60,6 +60,10 @@ const {
   deprecate,
   exposeInterface,
 } = require('internal/util');
+const {
+  exiting_aliased_Uint32Array,
+  getHiddenValue,
+} = internalBinding('util');
 
 setupProcessObject();
 
@@ -67,10 +71,25 @@ setupGlobalProxy();
 setupBuffer();
 
 process.domain = null;
+{
+  const exitingAliasedUint32Array =
+    getHiddenValue(process, exiting_aliased_Uint32Array);
+  ObjectDefineProperty(process, '_exiting', {
+    __proto__: null,
+    get() {
+      return exitingAliasedUint32Array[0] === 1;
+    },
+    set(value) {
+      exitingAliasedUint32Array[0] = value ? 1 : 0;
+    },
+    enumerable: true,
+    configurable: true,
+  });
+}
 process._exiting = false;
 
 // process.config is serialized config.gypi
-const nativeModule = internalBinding('native_module');
+const nativeModule = internalBinding('builtins');
 
 // TODO(@jasnell): Once this has gone through one full major
 // release cycle, remove the Proxy and setter and update the
@@ -402,6 +421,7 @@ function setupGlobalProxy() {
     enumerable: false,
     configurable: true
   });
+  globalThis.global = globalThis;
 }
 
 function setupBuffer() {
