@@ -28,7 +28,7 @@ const { readFileSync } = require('fs');
 const { extname, isAbsolute } = require('path');
 const {
   hasEsmSyntax,
-  loadNativeModule,
+  loadBuiltinModule,
   stripBOM,
 } = require('internal/modules/cjs/helpers');
 const {
@@ -255,7 +255,7 @@ translators.set('builtin', async function builtinStrategy(url) {
   debug(`Translating BuiltinModule ${url}`);
   // Slice 'node:' scheme
   const id = StringPrototypeSlice(url, 5);
-  const module = loadNativeModule(id, url);
+  const module = loadBuiltinModule(id, url);
   if (!StringPrototypeStartsWith(url, 'node:') || !module) {
     throw new ERR_UNKNOWN_BUILTIN_MODULE(url);
   }
