@@ -36,7 +36,6 @@ const {
 const FixedQueue = require('internal/fixed_queue');
 
 const {
-  validateCallback,
   validateFunction,
 } = require('internal/validators');
 
@@ -68,7 +67,7 @@ function runNextTicks() {
 function processTicksAndRejections() {
   let tock;
   do {
-    while (tock = queue.shift()) {
+    while ((tock = queue.shift()) !== null) {
       const asyncId = tock[async_id_symbol];
       emitBefore(asyncId, tock[trigger_async_id_symbol], tock);
 
@@ -102,7 +101,7 @@ function processTicksAndRejections() {
 // `nextTick()` will not enqueue any callback when the process is about to
 // exit since the callback would not have a chance to be executed.
 function nextTick(callback) {
-  validateCallback(callback);
+  validateFunction(callback, 'callback');
 
   if (process._exiting)
     return;
