@@ -8,9 +8,13 @@ const {
   codes,
 } = require('internal/errors');
 const {
+  ERR_INVALID_ARG_TYPE,
   ERR_STREAM_PREMATURE_CLOSE
 } = codes;
-const { once } = require('internal/util');
+const {
+  kEmptyObject,
+  once,
+} = require('internal/util');
 const {
   validateAbortSignal,
   validateFunction,
@@ -24,9 +28,11 @@ const {
   isReadable,
   isReadableNodeStream,
   isReadableFinished,
+  isReadableErrored,
   isWritable,
   isWritableNodeStream,
   isWritableFinished,
+  isWritableErrored,
   isNodeStream,
   willEmitClose: _willEmitClose,
 } = require('internal/streams/utils');
@@ -40,9 +46,9 @@ const nop = () => {};
 function eos(stream, options, callback) {
   if (arguments.length === 2) {
     callback = options;
-    options = {};
+    options = kEmptyObject;
   } else if (options == null) {
-    options = {};
+    options = kEmptyObject;
   } else {
     validateObject(options, 'options');
   }
@@ -56,7 +62,7 @@ function eos(stream, options, callback) {
 
   if (!isNodeStream(stream)) {
     // TODO: Webstreams.
-    // TODO: Throw INVALID_ARG_TYPE.
+    throw new ERR_INVALID_ARG_TYPE('stream', 'Stream', stream);
   }
 
   const wState = stream._writableState;
@@ -124,7 +130,7 @@ function eos(stream, options, callback) {
   const onclose = () => {
     closed = true;
 
-    const errored = wState?.errored || rState?.errored;
+    const errored = isWritableErrored(stream) || isReadableErrored(stream);
 
     if (errored && typeof errored !== 'boolean') {
       return callback.call(stream, errored);
