@@ -12,18 +12,14 @@ function cleanupStaleProcess(filename) {
   }
   process.once('beforeExit', () => {
     const basename = filename.replace(/.*[/\\]/g, '');
-    try {
-      require('child_process')
-        .execFileSync(`${process.env.SystemRoot}\\System32\\wbem\\WMIC.exe`, [
-          'process',
-          'where',
-          `commandline like '%${basename}%child'`,
-          'delete',
-          '/nointeractive',
-        ]);
-    } catch {
-      // Ignore failures, there might not be any stale process to clean up.
-    }
+    require('child_process')
+      .execFileSync(`${process.env.SystemRoot}\\System32\\wbem\\WMIC.exe`, [
+        'process',
+        'where',
+        `commandline like '%${basename}%child'`,
+        'delete',
+        '/nointeractive',
+      ]);
   });
 }
 
